@@ -16,7 +16,7 @@ use Class::XSAccessor::Array {
         expiry => RETIDX_EXP,
         _cas => RETIDX_CAS,
         value => RETIDX_VALUE,
-        errnum => RETIDX_ERRNUM
+        errnum => RETIDX_ERRNUM,
     }
 };
 
@@ -67,7 +67,6 @@ sub copy {
     bless my $cp = [@$self], 'Couchbase::Document';
 
     $cp->_cas(0);
-    $cp->[RETIDX_PARENT] = undef;
     return $cp;
 }
 
